@@ -6,7 +6,6 @@ require 'compass/exec'
 include Compass::TestCaseHelper
 include Compass::CommandLineHelper
 include Compass::IoHelper
-include Compass::RailsHelper
 
 Before do
   Compass.reset_configuration!
@@ -41,16 +40,6 @@ Given %r{^I am in the parent directory$} do
   Dir.chdir ".."
 end
 
-Given %r{^I'm in a newly created rails project: (.+)$} do |project_name|
-  @cleanup_directories << project_name
-  begin
-    generate_rails_app project_name
-    Dir.chdir project_name
-  rescue LoadError
-    pending "Missing Ruby-on-rails gems: sudo gem install rails"
-  end
-end
-
 Given /^I should clean up the directory: (\w+)$/ do |directory|
   @cleanup_directories << directory
 end
@@ -135,13 +124,14 @@ end
 
 Then "the following files are reported removed:" do |table|
   table.rows.each do |css_file|
-    Then %Q{a css file #{css_file.first} is reported removed}
+    #need to find a better way but this works for now
+    step %Q{a css file #{css_file.first} is reported removed}
   end
 end
 
 Then "the following files are removed:" do |table|
   table.rows.each do |css_file|
-    Then %Q{a css file #{css_file.first} is removed}
+    step %Q{a css file #{css_file.first} is removed}
   end
 end
 
@@ -257,7 +247,7 @@ end
 Then /^I should see the following "([^"]+)" commands:$/ do |kind, table|
 
 
-  Then %Q{I should be shown a list of "#{kind}" commands}
+  step %Q{I should be shown a list of "#{kind}" commands}
 
   commands = @last_command_list.map{|c| c =~ /^\s+\* ([^ ]+)\s+- [A-Z].+$/; [$1]}
   table.diff!(commands)
@@ -266,7 +256,7 @@ end
 
 Then /^the image ([^ ]+) has a size of (\d+)x(\d+)$/ do |file, width, height| 
   # see http://snippets.dzone.com/posts/show/805
-  IO.read(file)[0x10..0x18].unpack('NN').should == [width.to_i, height.to_i]
+  open(file, "rb").read[0x10..0x18].unpack('NN').should == [width.to_i, height.to_i]
 end
 
 Then /^I should see the following lines of output:$/ do |table|
